<div class="card mb-2">
    <div class="card-header" role="tab">
        <h5 class="mb-0">
            <a data-toggle="collapse" href="#{{ div.css_id }}" aria-expanded="true"
               aria-controls="{{ div.css_id }}">
                {{ div.name }}
            </a>
        </h5>
    </div>

    <div id="{{ div.css_id }}" class="collapse{% if div.active %} show{% endif %}" role="tabpanel"
         aria-labelledby="{{ div.css_id }}" data-parent="#{{ div.data_parent }}">
        <div class="card-body">
            {{ fields }}
        </div>
    </div>
</div>
